@@ -39,6 +39,8 @@ def oai_to_s3(**kwargs):
             data = harvest_oai(**kwargs)
             if data == []:
                 sets_with_no_records.append(oai_set)
+                logging.info("Skipping processing % set because it has no data.", oai_set)
+                continue
             outdir = dag_s3_prefix(dag_id, dag_start_date)
             processed = process_xml(data, dag_write_string_to_s3, outdir, **kwargs)
             all_processed.append(processed)
@@ -151,7 +153,7 @@ class OaiXml:
         self.root.append(record)
 
     def tostring(self):
-       return etree.tostring(self.root).decode("utf-8")
+        return etree.tostring(self.root, encoding="utf-8").decode("utf-8")
 
 
 def process_xml(data, writer, outdir, **kwargs):
